unit WebCoreEmsResource;
// EMS Resource Module
interface
uses
  System.SysUtils, System.Classes, System.JSON,
  EMS.Services, EMS.ResourceAPI, EMS.ResourceTypes, Data.Win.ADODB, Data.DB;

type
  [ResourceName('WebCoreEMS')]
  TWebCoreEMSResource1 = class(TDataModule)
    ADOConnection1: TADOConnection;
    qrySelectCustomers: TADODataSet;
    qrySelectCustomersCustomerID: TWideStringField;
    qrySelectCustomersCompanyName: TWideStringField;
    qrySelectCustomersContactName: TWideStringField;
    qrySelectCustomersContactTitle: TWideStringField;
    qrySelectCustomersAddress: TWideStringField;
    qrySelectCustomersCity: TWideStringField;
    qrySelectCustomersRegion: TWideStringField;
    qrySelectCustomersPostalCode: TWideStringField;
    qrySelectCustomersCountry: TWideStringField;
    qrySelectCustomersPhone: TWideStringField;
    qrySelectCustomersFax: TWideStringField;
    qryUpdateCustomer: TADOCommand;
  published
    procedure Get(const AContext: TEndpointContext; const ARequest: TEndpointRequest; const AResponse: TEndpointResponse);
    [ResourceSuffix('{item}')]
    procedure GetItem(const AContext: TEndpointContext; const ARequest: TEndpointRequest; const AResponse: TEndpointResponse);
    [ResourceSuffix('UpdateCustomer/{CustomerID}/{CompanyName}/{ContactName}')]
    procedure Post(const AContext: TEndpointContext; const ARequest: TEndpointRequest; const AResponse: TEndpointResponse);
  end;

implementation
uses
  Customers;

{%CLASSGROUP 'System.Classes.TPersistent'}

{$R *.dfm}

procedure TWebCoreEMSResource1.Get(const AContext: TEndpointContext; const ARequest: TEndpointRequest; const AResponse: TEndpointResponse);
var
  Custs: TCustomers;
begin
  qrySelectCustomers.Close;
  qrySelectCustomers.Open;
  Custs := TCustomers.Create;
  try
    Custs.Read(qrySelectCustomers);
    AResponse.StatusCode := 200;
    AResponse.Body.SetBytes(TEncoding.ASCII.GetBytes(Custs.ToJSON), 'application/json');
  finally
    Custs.Free
  end;
end;

procedure TWebCoreEMSResource1.GetItem(const AContext: TEndpointContext; const ARequest: TEndpointRequest; const AResponse: TEndpointResponse);
var
  Custs: TCustomers;
  CustomerID: string;
begin
  CustomerID := ARequest.Params.Values['item'];
  qrySelectCustomers.Close;
  qrySelectCustomers.Open;
  qrySelectCustomers.Filter := 'CustomerID = ''' +  CustomerID + '''';
  qrySelectCustomers.Filtered := True;
  Custs := TCustomers.Create;
  try
    Custs.Read(qrySelectCustomers);
    AResponse.StatusCode := 200;
    AResponse.Body.SetBytes(TEncoding.ASCII.GetBytes(Custs.ToJSON), 'application/json');
  finally
    qrySelectCustomers.Filtered := False;
    Custs.Free
  end;
end;

procedure TWebCoreEMSResource1.Post(const AContext: TEndpointContext; const ARequest: TEndpointRequest; const AResponse: TEndpointResponse);
begin
  qryUpdateCustomer.Parameters.ParamByName('CustomerID').Value := ARequest.Params.Values['CustomerID'];
  qryUpdateCustomer.Parameters.ParamByName('CompanyName').Value := ARequest.Params.Values['CompanyName'];
  qryUpdateCustomer.Parameters.ParamByName('ContactName').Value := ARequest.Params.Values['ContactName'];
  try
    qryUpdateCustomer.Execute;
    AResponse.StatusCode := 200;
    AResponse.Body.SetBytes(BytesOf('OK'), 'text/plain');
  except
    on E: Exception do
      AResponse.Body.SetBytes(BytesOf(E.Message), 'text/plain');
  end;
end;

procedure Register;
begin
  RegisterResource(TypeInfo(TWebCoreEMSResource1));
end;

initialization
  Register;
end.


